/**
 * BladeX Commercial License Agreement
 * Copyright (c) 2018-2099, https://bladex.cn. All rights reserved.
 * <p>
 * Use of this software is governed by the Commercial License Agreement
 * obtained after purchasing a license from BladeX.
 * <p>
 * 1. This software is for development use only under a valid license
 * from BladeX.
 * <p>
 * 2. Redistribution of this software's source code to any third party
 * without a commercial license is strictly prohibited.
 * <p>
 * 3. Licensees may copyright their own code but cannot use segments
 * from this software for such purposes. Copyright of this software
 * remains with BladeX.
 * <p>
 * Using this software signifies agreement to this License, and the software
 * must not be used for illegal purposes.
 * <p>
 * Author: Chill Zhuang (bladejava@qq.com)
 */
package org.springblade.transport.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.ibatis.annotations.Param;
import org.springblade.transport.pojo.entity.CommonAddress;
import org.springblade.transport.pojo.vo.CommonAddressVO;

import java.util.List;

/**
 * 常用地址 Mapper 接口
 *
 * @author Chill
 */
public interface CommonAddressMapper extends BaseMapper<CommonAddress> {

	/**
	 * 自定义分页
	 *
	 * @param page 分页参数
	 * @param address 查询参数
	 * @return 常用地址列表
	 */
	List<CommonAddressVO> selectCommonAddressPage(IPage<CommonAddressVO> page, @Param("address") CommonAddressVO address);

	/**
	 * 查询当前最大地址编号
	 *
	 * @return 最大地址编号
	 */
	String selectMaxAddressCode();

	/**
	 * 查询港口码头来源
	 *
	 * @param id 主键
	 * @return 来源地址
	 */
	CommonAddressVO selectPortTerminalSource(@Param("id") Long id);

	/**
	 * 查询铁路车站来源
	 *
	 * @param id 主键
	 * @return 来源地址
	 */
	CommonAddressVO selectRailwayStationSource(@Param("id") Long id);

	/**
	 * 查询空港机场来源
	 *
	 * @param id 主键
	 * @return 来源地址
	 */
	CommonAddressVO selectAirportMasterSource(@Param("id") Long id);

	/**
	 * 查询可选来源地址
	 *
	 * @param addressType 地址类型
	 * @param keyword 关键字
	 * @return 来源地址
	 */
	List<CommonAddressVO> selectSourceOptions(@Param("addressType") String addressType, @Param("keyword") String keyword);

	/**
	 * 查询业务引用数
	 *
	 * @param addressId 常用地址ID
	 * @return 引用数
	 */
	Integer countBusinessReference(@Param("addressId") Long addressId);

}
